@@ -4,7 +4,8 @@
 #' @export
 arrange.vital <- function(.data, ...) {
   vvar <- vital_var_list(.data)
-  as_vital(NextMethod(),
+  as_vital(
+    NextMethod(),
     .age = vvar$age,
     .sex = vvar$sex,
     .deaths = vvar$deaths,
@@ -16,7 +17,8 @@ arrange.vital <- function(.data, ...) {
 #' @export
 select.vital <- function(.data, ...) {
   vvar <- vital_var_list(.data)
-  as_vital(NextMethod(),
+  as_vital(
+    NextMethod(),
     .age = vvar$age,
     .sex = vvar$sex,
     .deaths = vvar$deaths,
@@ -28,7 +30,8 @@ select.vital <- function(.data, ...) {
 #' @export
 transmute.vital <- function(.data, ...) {
   vvar <- vital_var_list(.data)
-  as_vital(NextMethod(),
+  as_vital(
+    NextMethod(),
     .age = vvar$age,
     .sex = vvar$sex,
     .deaths = vvar$deaths,
@@ -40,7 +43,8 @@ transmute.vital <- function(.data, ...) {
 #' @exportS3Method dplyr::relocate
 relocate.vital <- function(.data, ...) {
   vvar <- vital_var_list(.data)
-  as_vital(NextMethod(),
+  as_vital(
+    NextMethod(),
     .age = vvar$age,
     .sex = vvar$sex,
     .deaths = vvar$deaths,
@@ -52,7 +56,8 @@ relocate.vital <- function(.data, ...) {
 #' @export
 summarise.vital <- function(.data, ..., .groups = NULL) {
   vvar <- vital_var_list(.data)
-  as_vital(NextMethod(),
+  as_vital(
+    NextMethod(),
     .age = vvar$age,
     .sex = vvar$sex,
     .deaths = vvar$deaths,
@@ -64,7 +69,8 @@ summarise.vital <- function(.data, ..., .groups = NULL) {
 #' @exportS3Method dplyr::dplyr_row_slice
 dplyr_row_slice.vital <- function(data, i, ..., preserve = FALSE) {
   vvar <- vital_var_list(data)
-  as_vital(NextMethod(),
+  as_vital(
+    NextMethod(),
     .age = vvar$age,
     .sex = vvar$sex,
     .deaths = vvar$deaths,
@@ -76,7 +82,8 @@ dplyr_row_slice.vital <- function(data, i, ..., preserve = FALSE) {
 #' @exportS3Method dplyr::dplyr_col_modify
 dplyr_col_modify.vital <- function(data, cols) {
   vvar <- vital_var_list(data)
-  as_vital(NextMethod(),
+  as_vital(
+    NextMethod(),
     .age = vvar$age,
     .sex = vvar$sex,
     .deaths = vvar$deaths,
@@ -88,7 +95,8 @@ dplyr_col_modify.vital <- function(data, cols) {
 #' @exportS3Method dplyr::dplyr_reconstruct
 dplyr_reconstruct.vital <- function(data, template) {
   vvar <- vital_var_list(data)
-  as_vital(NextMethod(),
+  as_vital(
+    NextMethod(),
     .age = vvar$age,
     .sex = vvar$sex,
     .deaths = vvar$deaths,
@@ -98,10 +106,15 @@ dplyr_reconstruct.vital <- function(data, template) {
 }
 
 #' @export
-group_by.vital <- function(.data, ..., .add = FALSE,
-                           .drop = group_by_drop_default(.data)) {
+group_by.vital <- function(
+  .data,
+  ...,
+  .add = FALSE,
+  .drop = group_by_drop_default(.data)
+) {
   vvar <- vital_var_list(.data)
-  tmp <- as_vital(NextMethod(),
+  tmp <- as_vital(
+    NextMethod(),
     .age = vvar$age,
     .sex = vvar$sex,
     .deaths = vvar$deaths,
@@ -110,14 +123,19 @@ group_by.vital <- function(.data, ..., .add = FALSE,
   )
   tmp_class <- class(tmp)
   grouped_classes <- grepl("grouped", tmp_class)
-  class(tmp) <- c("grouped_vital", tmp_class[grouped_classes], tmp_class[!grouped_classes])
+  class(tmp) <- c(
+    "grouped_vital",
+    tmp_class[grouped_classes],
+    tmp_class[!grouped_classes]
+  )
   return(tmp)
 }
 
 #' @export
 ungroup.grouped_vital <- function(x, ...) {
   vvar <- vital_var_list(x)
-  as_vital(NextMethod(),
+  as_vital(
+    NextMethod(),
     .age = vvar$age,
     .sex = vvar$sex,
     .deaths = vvar$deaths,
@@ -147,7 +165,8 @@ dplyr_col_modify.grouped_vital <- dplyr_col_modify.vital
 #' @exportS3Method dplyr::dplyr_reconstruct
 dplyr_reconstruct.grouped_vital <- function(data, template) {
   vvar <- vital_var_list(data)
-  as_vital(NextMethod(),
+  as_vital(
+    NextMethod(),
     .age = vvar$age,
     .sex = vvar$sex,
     .deaths = vvar$deaths,
@@ -161,7 +180,8 @@ dplyr_reconstruct.grouped_vital <- function(data, template) {
   vvar <- vital_var_list(x)
   res <- NextMethod()
   if (inherits(res, "tbl_ts")) {
-    as_vital(res,
+    as_vital(
+      res,
       .age = vvar$age,
       .sex = vvar$sex,
       .deaths = vvar$deaths,
@@ -172,3 +192,16 @@ dplyr_reconstruct.grouped_vital <- function(data, template) {
     res
   }
 }
+
+#' @export
+rename.vital <- function(.data, ...) {
+  vvar <- vital_var_list(.data)
+  as_vital(
+    NextMethod(),
+    .age = vvar$age,
+    .sex = vvar$sex,
+    .deaths = vvar$deaths,
+    .births = vvar$births,
+    .population = vvar$population
+  )
+}
