@@ -33,13 +33,30 @@
 #' @seealso [tsibble::tsibble()]
 #' @export
 vital <- function(
-    ..., key = NULL, index,
-    .age = NULL, .sex = NULL, .deaths = NULL, .births = NULL, .population = NULL,
-    regular = TRUE, .drop = TRUE) {
-  tsibble(..., key = !!enquo(key), index = !!enquo(index), regular = regular, .drop = .drop) |>
+  ...,
+  key = NULL,
+  index,
+  .age = NULL,
+  .sex = NULL,
+  .deaths = NULL,
+  .births = NULL,
+  .population = NULL,
+  regular = TRUE,
+  .drop = TRUE
+) {
+  tsibble(
+    ...,
+    key = !!enquo(key),
+    index = !!enquo(index),
+    regular = regular,
+    .drop = .drop
+  ) |>
     as_vital(
-      .age = .age, .sex = .sex, .deaths = .deaths,
-      births = .births, population = .population
+      .age = .age,
+      .sex = .sex,
+      .deaths = .deaths,
+      .births = .births,
+      .population = .population
     )
 }
 
@@ -47,7 +64,7 @@ vital <- function(
 #' @export
 as_vital.vital <- function(x, index, keys, ...) {
   as_tibble(x) |>
-    as_tsibble(index= !!enquo(index), key = !!enquo(keys)) |>
+    as_tsibble(index = !!enquo(index), key = !!enquo(keys)) |>
     as_vital(...)
 }
 
@@ -87,7 +104,7 @@ as_vital.demogdata <- function(x, sex_groups = TRUE, ...) {
     rates <- NULL
     for (i in seq_along(x$rate)) {
       tmp <- x$rate[[i]] |>
-        tibble::as_tibble() |>
+        tsibble::as_tibble() |>
         mutate(
           AgeGroup = rownames(x$rate[[i]]),
           Age = x$age
@@ -130,18 +147,32 @@ as_vital.demogdata <- function(x, sex_groups = TRUE, ...) {
     }
   }
   if (rates_included & pop_included) {
-    output <- dplyr::full_join(rates, pop, by = c("Group", "Year", "AgeGroup", "Age"))
+    output <- dplyr::full_join(
+      rates,
+      pop,
+      by = c("Group", "Year", "AgeGroup", "Age")
+    )
     if ("Mortality" %in% colnames(output) & "Exposure" %in% colnames(output)) {
       output <- output |>
         mutate(
           Deaths = if_else(is.na(Mortality), 0, Exposure * Mortality),
-          Mortality = if_else(is.na(Mortality) & Exposure > 0 & Deaths == 0, 0, Mortality)
+          Mortality = if_else(
+            is.na(Mortality) & Exposure > 0 & Deaths == 0,
+            0,
+            Mortality
+          )
         )
-    } else if ("Fertility" %in% colnames(output) & "Exposure" %in% colnames(output)) {
+    } else if (
+      "Fertility" %in% colnames(output) & "Exposure" %in% colnames(output)
+    ) {
       output <- output |>
         mutate(
           Births = if_else(is.na(Fertility), 0, Exposure * Fertility / 1000),
-          Fertility = if_else(is.na(Fertility) & Exposure > 0 & Births == 0, 0, Fertility)
+          Fertility = if_else(
+            is.na(Fertility) & Exposure > 0 & Births == 0,
+            0,
+            Fertility
+          )
         )
     }
   }
@@ -170,9 +201,13 @@ as_vital.demogdata <- function(x, sex_groups = TRUE, ...) {
   } else if ("Population" %in% colnames(output)) {
     popvar <- "Population"
   }
-  as_vital(output,
-    .age = "Age", .sex = sexvar, .deaths = deathsvar,
-    .births = birthsvar, .population = popvar
+  as_vital(
+    output,
+    .age = "Age",
+    .sex = sexvar,
+    .deaths = deathsvar,
+    .births = birthsvar,
+    .population = popvar
   )
 }
 
@@ -184,36 +219,84 @@ as_vital.demogdata <- function(x, sex_groups = TRUE, ...) {
 #' @param reorder Logical indicating if the variables should be reordered.
 #' @rdname as_vital
 #' @export
-as_vital.tbl_ts <- function(x,
-    .age = NULL, .sex = NULL, .deaths = NULL, .births = NULL, .population = NULL,
-    reorder = FALSE, ...) {
+as_vital.tbl_ts <- function(
+  x,
+  .age = NULL,
+  .sex = NULL,
+  .deaths = NULL,
+  .births = NULL,
+  .population = NULL,
+  reorder = FALSE,
+  ...
+) {
   # Add attributes to x to identify the various variables
   vnames <- colnames(x)
-  if(!is.null(.age)) {
-    if(!(.age %in% vnames)) { .age <- NULL }
+  if (!is.null(.age)) {
+    if (!(.age %in% vnames)) {
+      .age <- NULL
+    }
   }
-  if(!is.null(.sex)) {
-    if(!(.sex %in% vnames)) { .sex <- NULL }
+  if (!is.null(.sex)) {
+    if (!(.sex %in% vnames)) {
+      .sex <- NULL
+    }
   }
-  if(!is.null(.births)) {
-    if(!(.births %in% vnames)) { .births <- NULL }
+  if (!is.null(.births)) {
+    if (!(.births %in% vnames)) {
+      .births <- NULL
+    }
   }
-  if(!is.null(.deaths)) {
-    if(!(.deaths %in% vnames)) { .deaths <- NULL }
+  if (!is.null(.deaths)) {
+    if (!(.deaths %in% vnames)) {
+      .deaths <- NULL
+    }
   }
-  if(!is.null(.population)) {
-    if(!(.population %in% vnames)) { .population <- NULL }
+  if (!is.null(.population)) {
+    if (!(.population %in% vnames)) {
+      .population <- NULL
+    }
   }
-  attr(x, "vital")  <- c(age = .age, sex = .sex,
-    deaths = .deaths, births = .births, population = .population)
+  attr(x, "vital") <- c(
+    age = .age,
+    sex = .sex,
+    deaths = .deaths,
+    births = .births,
+    population = .population
+  )
   # Add additional class
   class(x) <- c("vital", class(x))
+  # Check class of variables
+  if (!is.null(.age)) {
+    if (!is.numeric(x[[.age]])) {
+      stop("Age variable must be numeric")
+    }
+  }
+  if (!is.null(.sex)) {
+    if (!is.factor(x[[.sex]]) & !is.character((x[[.sex]]))) {
+      stop("Sex variable must be character or factor")
+    }
+  }
+  if (!is.null(.births)) {
+    if (!is.numeric(x[[.births]])) {
+      stop("Births variable must be numeric")
+    }
+  }
+  if (!is.null(.deaths)) {
+    if (!is.numeric(x[[.deaths]])) {
+      stop("Deaths variable must be numeric")
+    }
+  }
+  if (!is.null(.population)) {
+    if (!is.numeric(x[[.population]])) {
+      stop("Population variable must be numeric")
+    }
+  }
   # Sort variables
   if (reorder) {
     agevar <- age_var(x)
     keys <- key_vars(x)
     agevars <- colnames(x)
-    agevars <- agevars[grep("age", agevars, ignore.case=TRUE)]
+    agevars <- agevars[grep("age", agevars, ignore.case = TRUE)]
     keys_noage <- keys[!(keys %in% c(agevar, agevars))]
     x <- select(x, all_of(c(index_var(x), agevar)), everything()) |>
       arrange(across(all_of(c(index_var(x), keys_noage, agevar))))
@@ -229,7 +312,7 @@ as_vital.tbl_ts <- function(x,
 #' @rdname as_vital
 #' @examples
 #' # create a vital with only age as a key
-#' tibble::tibble(
+#' data.frame(
 #'   year = rep(2010:2015, 100),
 #'   age = rep(0:99, each = 6),
 #'   mx = runif(600, 0, 1)
@@ -240,14 +323,24 @@ as_vital.tbl_ts <- function(x,
 #'     .age = "age"
 #'   )
 #' @export
-as_vital.data.frame <- function(x, key = NULL, index,
-    .age = NULL, .sex = NULL, .deaths = NULL, .births = NULL, .population = NULL,
-    reorder = TRUE,
-    ...) {
+as_vital.data.frame <- function(
+  x,
+  key = NULL,
+  index,
+  .age = NULL,
+  .sex = NULL,
+  .deaths = NULL,
+  .births = NULL,
+  .population = NULL,
+  reorder = TRUE,
+  ...
+) {
   as_tsibble(x, key = !!enquo(key), index = !!enquo(index), ...) |>
     as_vital(
-      .age = .age, .sex = .sex,
-      .deaths = .deaths, .births = .births,
+      .age = .age,
+      .sex = .sex,
+      .deaths = .deaths,
+      .births = .births,
       .population = .population,
       reorder = reorder
     )
@@ -271,18 +364,18 @@ tbl_sum.vital <- function(x) {
     first
   } else {
     age_key <- vital_var_list(x)$age
-    if(!is.null(age_key)) {
+    if (!is.null(age_key)) {
       keys_noage <- keys[!(keys %in% age_key)]
-      if(length(keys_noage) > 1) {
-        keys <- paste0(age_key, " x (", comma(keys_noage),")")
-      } else if(length(keys_noage) == 1L) {
+      if (length(keys_noage) > 1) {
+        keys <- paste0(age_key, " x (", comma(keys_noage), ")")
+      } else if (length(keys_noage) == 1L) {
         keys <- paste0(age_key, " x ", comma(keys_noage))
       } else {
         keys <- age_key
       }
       nages <- length(unique(x[[age_key]]))
-      nkeys_noage <- n_keys/nages
-      n_keys <- paste(big_mark(nages),"x",big_mark(nkeys_noage))
+      nkeys_noage <- n_keys / nages
+      n_keys <- paste(big_mark(nages), "x", big_mark(nkeys_noage))
     } else {
       n_keys <- big_mark(n_keys)
     }
